runner

Function runner 

pub fn runner(tests: &'static [&'static dyn TestCase]) -> !
A test runner that runs the given tests and exits QEMU after completion.

Output from this runner is formatted as line-delimited JSON and printed to the debug console. This allows for easy parsing of test results by external tools, such as kboot.